using DamageAssesment.Api.Answers.Db;
using DamageAssesment.Api.Answers.Interfaces;
using DamageAssesment.Api.Answers.Providers;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Options;
using Microsoft.OpenApi.Models;
using System.Reflection;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.

builder.Services.AddControllers();
// Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
builder.Services.AddEndpointsApiExplorer();
//builder.Services.AddSwaggerGen();
builder.Services.AddSwaggerGen(c =>
{
  
    // Include XML comments from your assembly
    var xmlFile = $"{Assembly.GetExecutingAssembly().GetName().Name}.xml";
    var xmlPath = Path.Combine(AppContext.BaseDirectory, xmlFile);
    c.IncludeXmlComments(xmlPath);
  

});
builder.Services.AddScoped<IAnswersProvider, AnswersProvider>();
builder.Services.AddAutoMapper(AppDomain.CurrentDomain.GetAssemblies()); //4/30
builder.Services.AddDbContext<AnswerDbContext>(option =>
{
    option.UseInMemoryDatabase("Answers");
});

var app = builder.Build();


// Configure the HTTP request pipeline.
if (app.Environment.IsDevelopment())
{
    //using (var serviceScope = app.Services.CreateScope())
    //{
    //    var services = serviceScope.ServiceProvider;
    //    var answerProvider = services.GetRequiredService<IAnswersProvider>();
    //    answerProvider.SeedData();
    //}
    app.UseSwagger();
    app.UseSwaggerUI(
        options =>
    {
        //switch for local environment
        //options.SwaggerEndpoint("/swagger/v1/swagger.json", "");
        options.SwaggerEndpoint("/answers/swagger/v1/swagger.json","" );
        
    } );
}

app.UseAuthorization();

app.MapControllers();

app.Run();
