﻿using DamageAssesment.Api.SurveyResponses.Interfaces;
using DamageAssesment.Api.SurveyResponses.Models;
using Newtonsoft.Json;

namespace DamageAssesment.Api.SurveyResponses.Services
{
    public class QuestionServiceProvider : ServiceProviderBase, IQuestionServiceProvider
    {
        public QuestionServiceProvider(IConfiguration configuration, IHttpUtil httpUtil, ILogger<QuestionServiceProvider> logger) : base(configuration, httpUtil, logger, "/api/Questions", configuration.GetValue<string>("EndPointSettings:QuestionUrlBase"))
        {
        }

        public async Task<List<Question>> getQuestionsAsync()
        {
            try
            {
                var url = urlBase + ressource;
                var responseJsonString = await httpUtil.SendAsync(HttpMethod.Get, url, null);
                var questions = JsonConvert.DeserializeObject<List<Question>>(responseJsonString);

                if (questions == null || !questions.Any())
                    return new List<Question>();
                else return questions;
            }
            catch (Exception ex)
            {
                logger?.LogError($"Exception Found : {ex.Message} - Ref: QuestionServiceProvider.getQuestionsAsync()");
                return new List<Question>();
            }
        }

        public async Task<List<SurveyQuestions>> getSurveyQuestionsAsync(int surveyId)
        {
            try
            {
                var url = urlBase + "/api/GetSurveyQuestions/" + surveyId;
                var responseJsonString = await httpUtil.SendAsync(HttpMethod.Get, url, null);
                var questions = JsonConvert.DeserializeObject<List<SurveyQuestions>>(responseJsonString);

                if (questions == null || !questions.Any())
                    return new List<SurveyQuestions>() ;
                else return questions;
            }
            catch (Exception ex)
            {
                logger?.LogError($"Exception Found : {ex.Message} - Ref: QuestionServiceProvider.getSurveyQuestionsAsync()");
                return new List<SurveyQuestions>();
            }
        }


        public async Task<Question> getQuestionsAsync(int questionId)
        {
            try
            {
                var url = urlBase + "/api/Questions/" + questionId;
                var responseJsonString = await httpUtil.SendAsync(HttpMethod.Get, url, null);
                var question = JsonConvert.DeserializeObject<Question>(responseJsonString);

                if (question == null)
                    return null;
                else return question;
            }
            catch (Exception ex)
            {
                logger?.LogError($"Exception Found : {ex.Message} - Ref: QuestionServiceProvider.getQuestionsAsync(questionId)");
                return null;
            }
        }
    }
}
